@@ -4,6 +4,9 @@
 #include <errno.h>
 #include <netdb.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/socket.h>
+#include <sys/select.h>
 #include <netinet/in.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -12,8 +15,6 @@
 #include <string.h>
 #include <pwd.h>
 #include <signal.h>
-#include <sys/stat.h>
-#include <sys/socket.h>
 #include <ctype.h>
 #include <time.h>
 #include <unistd.h>
@@ -41,19 +42,18 @@ static char path[_POSIX_PATH_MAX];
 static char message[PIPE_BUF]; /* message buf used for communication */
 
 static void usage() {
-	fprintf(stderr, "%s",
-			"ii - irc it - " VERSION "\n"
-			"(C)opyright MMV-MMVI Anselm R. Garbe\n"
-			"(C)opyright MMV-MMXI Nico Golde\n"
-			"usage: ii [-i <irc dir>] [-s <host>] [-p <port>]\n"
-			"          [-n <nick>] [-k <password>] [-f <fullname>]\n");
-	exit(EXIT_SUCCESS);
+	fputs("ii - irc it - " VERSION "\n"
+	      "(C)opyright MMV-MMVI Anselm R. Garbe\n"
+	      "(C)opyright MMV-MMXI Nico Golde\n"
+	      "usage: ii [-i <irc dir>] [-s <host>] [-p <port>]\n"
+	      "          [-n <nick>] [-k <password>] [-f <fullname>]\n", stderr);
+	exit(EXIT_FAILURE);
 }
 
 static char *striplower(char *s) {
 	char *p = NULL;
 	for(p = s; p && *p; p++) {
-		if(*p == '/') *p = '_';
+		if(*p == '/') *p = ',';
 		*p = tolower(*p);
 	}
 	return s;
@@ -89,7 +89,7 @@ static int get_filepath(char *filepath, size_t len, char *channel, char *file) {
 
 static void create_filepath(char *filepath, size_t len, char *channel, char *suffix) {
 	if(!get_filepath(filepath, len, striplower(channel), suffix)) {
-		fprintf(stderr, "%s", "ii: path to irc directory too long\n");
+		fputs("ii: path to irc directory too long\n", stderr);
 		exit(EXIT_FAILURE);
 	}
 }
@@ -240,12 +240,10 @@ static void proc_channels_input(Channel *c, char *buf) {
 				else snprintf(message, PIPE_BUF, "JOIN %s\r\n", &buf[3]);
 				add_channel(&buf[3]);
 			}
-			else {
-				if(p){
-					add_channel(&buf[3]);
-					proc_channels_privmsg(&buf[3], p + 1);
-					return;
-				}
+			else if(p){
+				add_channel(&buf[3]);
+				proc_channels_privmsg(&buf[3], p + 1);
+				return;
 			}
 			break;
 		case 't':
@@ -350,13 +348,9 @@ static void proc_server_cmd(char *buf) {
 	} else if(!strncmp("ERROR", argv[TOK_CMD], 6))
 		snprintf(message, PIPE_BUF, "-!- error %s", argv[TOK_TEXT] ? argv[TOK_TEXT] : "unknown");
 	else if(!strncmp("JOIN", argv[TOK_CMD], 5)) {
-		if(argv[TOK_TEXT] != NULL){
-			p = strchr(argv[TOK_TEXT], ' ');
-			if(p)
-				*p = 0;
-		}
-		argv[TOK_CHAN] = argv[TOK_TEXT];
-		snprintf(message, PIPE_BUF, "-!- %s(%s) has joined %s", argv[TOK_NICKSRV], argv[TOK_USER], argv[TOK_TEXT]);
+		if (argv[TOK_TEXT] != NULL)
+			argv[TOK_CHAN] = argv[TOK_TEXT];
+		snprintf(message, PIPE_BUF, "-!- %s(%s) has joined %s", argv[TOK_NICKSRV], argv[TOK_USER], argv[TOK_CHAN]);
 	} else if(!strncmp("PART", argv[TOK_CMD], 5)) {
 		snprintf(message, PIPE_BUF, "-!- %s(%s) has left %s", argv[TOK_NICKSRV], argv[TOK_USER], argv[TOK_CHAN]);
 	} else if(!strncmp("MODE", argv[TOK_CMD], 5))
@@ -467,7 +461,7 @@ int main(int argc, char *argv[]) {
 	char prefix[_POSIX_PATH_MAX];
 
 	if(!spw) {
-		fprintf(stderr,"ii: getpwuid() failed\n");
+		fputs("ii: getpwuid() failed\n", stderr);
 		exit(EXIT_FAILURE);
 	}
 	snprintf(nick, sizeof(nick), "%s", spw->pw_name);
@@ -480,14 +474,14 @@ int main(int argc, char *argv[]) {
 			case 's': host = argv[++i]; break;
 			case 'p': port = strtol(argv[++i], NULL, 10); break;
 			case 'n': snprintf(nick,sizeof(nick),"%s", argv[++i]); break;
-			case 'k': key = argv[++i]; break;
+			case 'k': key = getenv(argv[++i]); break;
 			case 'f': fullname = argv[++i]; break;
 			default: usage(); break;
 		}
 	}
 	irc = tcpopen(port);
 	if(!snprintf(path, sizeof(path), "%s/%s", prefix, host)) {
-		fprintf(stderr, "%s", "ii: path to irc directory too long\n");
+		fputs("ii: path to irc directory too long\n", stderr);
 		exit(EXIT_FAILURE);
 	}
 	create_dirtree(path);
@@ -496,5 +490,5 @@ int main(int argc, char *argv[]) {
 	login(key, fullname);
 	run();
 
-	return 0;
+	return EXIT_SUCCESS;
 }
